@@ -197,8 +197,7 @@ ev_annotation_window_dispose (GObject *object)
 
 	if (window->annotation) {
 		ev_annotation_window_sync_contents (window);
-		g_object_unref (window->annotation);
-		window->annotation = NULL;
+		g_clear_object (&window->annotation);
 	}
 
 	(* G_OBJECT_CLASS (ev_annotation_window_parent_class)->dispose) (object);
@@ -344,6 +343,9 @@ ev_annotation_window_init (EvAnnotationWindow *window)
 	g_signal_connect_swapped (window->close_button, "clicked",
 				  G_CALLBACK (ev_annotation_window_close),
 				  window);
+	/* Handle case when window is closed from outside Evince e.g. by desktop compositor */
+	g_signal_connect (GTK_WIDGET (window), "delete-event",
+			  G_CALLBACK (ev_annotation_window_close), NULL);
 
 	gtk_box_pack_start (GTK_BOX (hbox), window->close_button, FALSE, FALSE, 0);
 	gtk_widget_show (window->close_button);
