@@ -17,8 +17,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __EV_RECENT_VIEW_H__
-#define __EV_RECENT_VIEW_H__
+#pragma once
 
 #include <glib-object.h>
 #include <gtk/gtk.h>
@@ -49,5 +48,3 @@ GType      ev_recent_view_get_type (void) G_GNUC_CONST;
 GtkWidget *ev_recent_view_new      (void);
 
 G_END_DECLS
-
-#endif /* __EV_RECENT_VIEW_H__ */
