@@ -105,12 +105,12 @@ static void         adjustment_changed_cb                  (EvSidebarThumbnails
 static void         check_toggle_blank_first_dual_mode     (EvSidebarThumbnails     *sidebar_thumbnails);
 static void         check_toggle_blank_first_dual_mode_when_resizing (EvSidebarThumbnails *sidebar_thumbnails);
 
-G_DEFINE_TYPE_EXTENDED (EvSidebarThumbnails, 
-                        ev_sidebar_thumbnails, 
+G_DEFINE_TYPE_EXTENDED (EvSidebarThumbnails,
+                        ev_sidebar_thumbnails,
                         GTK_TYPE_BOX,
-                        0, 
+                        0,
                         G_ADD_PRIVATE (EvSidebarThumbnails)
-                        G_IMPLEMENT_INTERFACE (EV_TYPE_SIDEBAR_PAGE, 
+                        G_IMPLEMENT_INTERFACE (EV_TYPE_SIDEBAR_PAGE,
 					       ev_sidebar_thumbnails_page_iface_init))
 
 /* Thumbnails dimensions cache */
@@ -195,11 +195,7 @@ ev_thumbnails_size_cache_get_size (EvThumbsSizeCache *cache,
 static void
 ev_thumbnails_size_cache_free (EvThumbsSizeCache *cache)
 {
-	if (cache->sizes) {
-		g_free (cache->sizes);
-		cache->sizes = NULL;
-	}
-
+	g_clear_pointer (&cache->sizes, g_free);
 	g_free (cache);
 }
 
@@ -256,16 +252,13 @@ static void
 ev_sidebar_thumbnails_dispose (GObject *object)
 {
 	EvSidebarThumbnails *sidebar_thumbnails = EV_SIDEBAR_THUMBNAILS (object);
-	
-	if (sidebar_thumbnails->priv->loading_icons) {
-		g_hash_table_destroy (sidebar_thumbnails->priv->loading_icons);
-		sidebar_thumbnails->priv->loading_icons = NULL;
-	}
-	
+
+	g_clear_pointer (&sidebar_thumbnails->priv->loading_icons,
+			 g_hash_table_destroy);
+
 	if (sidebar_thumbnails->priv->list_store) {
 		ev_sidebar_thumbnails_clear_model (sidebar_thumbnails);
-		g_object_unref (sidebar_thumbnails->priv->list_store);
-		sidebar_thumbnails->priv->list_store = NULL;
+		g_clear_object (&sidebar_thumbnails->priv->list_store);
 	}
 
 	G_OBJECT_CLASS (ev_sidebar_thumbnails_parent_class)->dispose (object);
@@ -297,7 +290,7 @@ ev_sidebar_thumbnails_map (GtkWidget *widget)
 	sidebar = EV_SIDEBAR_THUMBNAILS (widget);
 
 	GTK_WIDGET_CLASS (ev_sidebar_thumbnails_parent_class)->map (widget);
-	
+
 	adjustment_changed_cb (sidebar);
 }
 
@@ -409,7 +402,7 @@ ev_sidebar_thumbnails_get_loading_icon (EvSidebarThumbnails *sidebar_thumbnails,
 	} else {
 		g_free (key);
 	}
-	
+
 	return icon;
 }
 
@@ -530,7 +523,7 @@ add_range (EvSidebarThumbnails *sidebar_thumbnails,
 					    COLUMN_JOB, job,
 					    -1);
 			ev_job_scheduler_push_job (EV_JOB (job), EV_JOB_PRIORITY_HIGH);
-			
+
 			/* The queue and the list own a ref to the job now */
 			g_object_unref (job);
 		} else if (job) {
@@ -567,12 +560,12 @@ update_visible_range (EvSidebarThumbnails *sidebar_thumbnails,
 	/* Clear the areas we no longer display */
 	if (old_start_page >= 0 && old_start_page < start_page)
 		cancel_running_jobs (sidebar_thumbnails, old_start_page, MIN (start_page - 1, old_end_page));
-	
+
 	if (old_end_page > 0 && old_end_page > end_page)
 		cancel_running_jobs (sidebar_thumbnails, MAX (end_page + 1, old_start_page), old_end_page);
 
 	add_range (sidebar_thumbnails, start_page, end_page);
-	
+
 	priv->start_page = start_page;
 	priv->end_page = end_page;
 }
@@ -641,7 +634,7 @@ ev_sidebar_thumbnails_fill_model (EvSidebarThumbnails *sidebar_thumbnails)
 
 		prev_width = width;
 		prev_height = height;
-		
+
 		gtk_list_store_append (priv->list_store, &iter);
 		gtk_list_store_set (priv->list_store, &iter,
 				    COLUMN_PAGE_STRING, page_string,
@@ -843,7 +836,7 @@ static gboolean
 refresh (EvSidebarThumbnails *sidebar_thumbnails)
 {
 	adjustment_changed_cb (sidebar_thumbnails);
-	return FALSE;
+	return G_SOURCE_REMOVE;
 }
 
 static void
@@ -1005,29 +998,29 @@ ev_sidebar_thumbnails_set_model (EvSidebarPage   *sidebar_page,
 }
 
 static gboolean
-ev_sidebar_thumbnails_clear_job (GtkTreeModel *model,                                             
+ev_sidebar_thumbnails_clear_job (GtkTreeModel *model,
 			         GtkTreePath *path,
 			         GtkTreeIter *iter,
 				 gpointer data)
 {
 	EvJob *job;
-	
+
 	gtk_tree_model_get (model, iter, COLUMN_JOB, &job, -1);
-	
+
 	if (job != NULL) {
 		ev_job_cancel (job);
 		g_signal_handlers_disconnect_by_func (job, thumbnail_job_completed_callback, data);
 		g_object_unref (job);
 	}
-	
-	return FALSE;    
+
+	return FALSE;
 }
 
-static void 
+static void
 ev_sidebar_thumbnails_clear_model (EvSidebarThumbnails *sidebar_thumbnails)
 {
 	EvSidebarThumbnailsPrivate *priv = sidebar_thumbnails->priv;
-	
+
 	gtk_tree_model_foreach (GTK_TREE_MODEL (priv->list_store), ev_sidebar_thumbnails_clear_job, sidebar_thumbnails);
 	gtk_list_store_clear (priv->list_store);
 }
